@@ -13,5 +13,11 @@ cd ../castle_game_engine/
 # Force rebuilding CastleWindow unit with proper backend.
 make clean-window
 
-fpc -dRELEASE ${CASTLE_FPC_OPTIONS:-} @castle-fpc.cfg ../view3dscene/view3dscene.lpr
+# fpc -dRELEASE ${CASTLE_FPC_OPTIONS:-} @castle-fpc.cfg ../view3dscene/view3dscene.lpr
+# Compile view3dscene binary using castle-engine,
+# this is good for Windows to include the icon/versioninfo/manfest in resources.
+cd ../view3dscene/
+castle-engine compile ${CASTLE_ENGINE_TOOL_OPTIONS:-}
+cd ../castle_game_engine/
+
 fpc -dRELEASE ${CASTLE_FPC_OPTIONS:-} @castle-fpc.cfg ../view3dscene/tovrmlx3d.lpr
